@@ -21,6 +21,8 @@
 #include <QScreen>
 #include <QStandardPaths>
 
+#include <print>
+#include <ranges>
 #include <utility>
 
 #include "../backendmanager_p.h"
@@ -521,6 +523,47 @@ void Doctor::parseOutputArgs()
                     }
                     output->setSharpness(sharpness / 100.0);
                     m_changed = true;
+                } else if (ops.count() >= 6 && subcmd == "addCustomMode") {
+                    auto modes = output->customModes();
+                    ModeInfo::Flags flags = ModeInfo::Flag::Custom;
+                    if (ops.count() > 6) {
+                        if (ops[6] == "reduced") {
+                            flags |= ModeInfo::Flag::ReducedBlanking;
+                        } else if (ops[6] != "full") {
+                            qCWarning(KSCREEN_DOCTOR) << "Invalid input: Only 'reduced' or 'full' allowed";
+                            qApp->exit(9);
+                            return;
+                        }
+                    }
+                    modes.push_back(ModeInfo{
+                        .size = QSize(ops[3].toUInt(), ops[4].toUInt()),
+                        .refreshRate = ops[5].toUInt() / 1000.0f,
+                        .flags = flags,
+                    });
+                    output->setCustomModes(modes);
+                    m_changed = true;
+                } else if (ops.count() == 4 && subcmd == "removeCustomMode") {
+                    auto modes = output->customModes();
+                    const int index = ops[3].toInt();
+                    if (index < 0 || index >= modes.size()) {
+                        qCWarning(KSCREEN_DOCTOR) << "Invalid index";
+                        qApp->exit(9);
+                        return;
+                    }
+                    modes.erase(modes.begin() + index);
+                    output->setCustomModes(modes);
+                    m_changed = true;
+                } else if (ops.count() >= 4 && subcmd == "autoBrightness") {
+                    if (ops[3] == "enable") {
+                        output->setAutomaticBrightness(true);
+                    } else if (ops[3] == "disable") {
+                        output->setAutomaticBrightness(false);
+                    } else {
+                        qCWarning(KSCREEN_DOCTOR) << "Invalid input: Only 'enable' and 'disable' are allowed";
+                        qApp->exit(9);
+                        return;
+                    }
+                    m_changed = true;
                 } else {
                     cerr << "Unable to parse arguments: " << op << Qt::endl;
                     qApp->exit(2);
@@ -609,6 +652,23 @@ void Doctor::showOutputs() const
             cout << " " << mode->id() << ":" << name << " ";
         }
         cout << endl;
+
+        cout << yellow << "\tCustom modes:" << cr;
+        const auto customModes = output->customModes();
+        if (customModes.empty()) {
+            cout << " None" << endl;
+        } else {
+            cout << endl;
+            for (const auto &[info, index] : std::views::zip(customModes, std::views::iota(0))) {
+                cout << "\t\t" << index << ": ";
+                cout << std::format("{}x{}@{:.2f}", info.size.width(), info.size.height(), info.refreshRate).c_str();
+                if (info.flags & ModeInfo::Flag::ReducedBlanking) {
+                    cout << " (reduced blanking)";
+                }
+                cout << endl;
+            }
+        }
+
         const auto g = output->geometry();
         cout << yellow << "\tGeometry: " << cr << g.x() << "," << g.y() << " " << g.width() << "x" << g.height() << endl;
         cout << yellow << "\tScale: " << cr << output->scale() << endl;
@@ -777,9 +837,15 @@ void Doctor::showOutputs() const
         if (output->capabilities() & Output::Capability::SharpnessControl) {
             cout << cr << "supported, set to " << std::round(output->sharpness() * 100) << "%"
                  << endl;
-         } else {
-             cout << cr << "unsupported" << endl;
-         }
+        } else {
+            cout << cr << "unsupported" << endl;
+        }
+        cout << yellow << "\tAutomatic brightness: ";
+        if (output->capabilities() & Output::Capability::AutomaticBrightness) {
+            cout << cr << "supported, " << (output->automaticBrightness() ? "enabled" : "disabled") << endl;
+        } else {
+            cout << cr << "unsupported" << endl;
+        }
     }
 }
 
